@@ -33,6 +33,7 @@
 #include <QtCore/QDebug>
 #include <QtCore/QMutex>
 #include <QtCore/QMutexLocker>
+#include <QtCore/QCoreApplication>
 
 #ifndef Q_OS_WIN
 #include <sys/types.h>
@@ -363,6 +364,12 @@ void Soprano::VirtuosoController::writeConfigFile( const QString& path, const Ba
         cfs.setValue( "MinAutoCheckpointSize", minAutoCheckpointSize );
 
     cfs.endGroup();
+
+    // normalize all free-text indexes and bif:contains terms (remove accents)
+    // Only supported by Virtuoso >= 6.2; older versions will simply ignore it
+    cfs.beginGroup( QLatin1String("I18N") );
+    cfs.setValue( QLatin1String("XAnyNormalization"), "3" );
+    cfs.endGroup();
 }
 
 
@@ -374,6 +381,9 @@ QString Soprano::VirtuosoController::locateVirtuosoBinary()
     const QString virtuosoHome = QDir::fromNativeSeparators( qgetenv("VIRTUOSO_HOME") );
     if ( !virtuosoHome.isEmpty() )
         dirs << virtuosoHome + QLatin1String("/bin");
+    else {
+        dirs << QCoreApplication::applicationDirPath();
+    }
 #endif
 
     foreach( const QString& dir, dirs ) {
